/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2008 OW2 consortium (www.ow2.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: XMLUtil.java 98 2006-02-24 16:18:48Z alouis $
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.commons.threadlocal;

import javax.xml.stream.XMLInputFactory;

/**
 * <p>
 * XML Input factories.
 * </p>
 * <p>
 * To avoid several instance of the same {@link XMLInputFactory} (with same options) in
 * the same Thread, each XMLInputFactory must be created using these factories.
 * </p>
 * 
 * @author Christophe DENEUX (Capgemini Sud)
 * 
 */
public final class XMLInputFactories {
    
    /**
     * <p>
     * {@link XMLInputFactory} as thread local.
     * </p>
     * <p>
     * The XML input factory is the one provided by the classpath.
     * </p>
     */
    private final static ThreadLocal<XMLInputFactory> defaultXifThreadLocal = new ThreadLocal<XMLInputFactory>() {

        @Override
        protected XMLInputFactory initialValue() {
            return XMLInputFactory.newInstance();
        }
    };

    /**
     * <p>
     * {@link XMLInputFactory} as thread local.
     * </p>
     * <p>
     * The XML input factory is the one provided by {@link #defaultXifThreadLocal}.
     * </p>
     */
     public final static XMLInputFactory getDefaultXMLInputFactory() {
        return XMLInputFactories.defaultXifThreadLocal.get();
    }

    
}
